Package: pdynmc
Type: Package
Title: Moment Condition Based Estimation of Linear Dynamic Panel Data
        Models
Version: 0.9.12
Date: 2025-02-20
Authors@R: c(person("Markus", "Fritsch", role = c("aut", "cre"),
		email = "Markus.Fritsch@uni-Passau.de"),
	person("Joachim", "Schnurbus", role = c("aut"),
		email = "Joachim.Schnurbus@uni-Passau.de"),
	person("Andrew Adrian Yu", "Pua", role = c("aut"),
		email = "andrewypua@gmail.com"))
Depends: R (>= 3.6.0)
Imports: data.table (>= 1.12.2), MASS (>= 7.3-51.4), Matrix (>=
        1.2-17), methods(>= 3.6.2), optimx (>= 2018-07.10), stats (>=
        3.6.0), Rdpack (>= 0.11-0)
Suggests: pder (>= 1.0-1), testthat (>= 2.3.2), R.rsp (>= 0.43.2)
RdMacros: Rdpack
Description: Linear dynamic panel data modeling based on linear and
    nonlinear moment conditions as proposed by
    Holtz-Eakin, Newey, and Rosen (1988) <doi:10.2307/1913103>,
    Ahn and Schmidt (1995) <doi:10.1016/0304-4076(94)01641-C>,
    and Arellano and Bover (1995) <doi:10.1016/0304-4076(94)01642-D>.
    Estimation of the model parameters relies on the Generalized
    Method of Moments (GMM) and instrumental variables (IV) estimation,
    numerical optimization (when nonlinear moment conditions are
    employed) and the computation of closed form solutions (when
    estimation is based on linear moment conditions). One-step,
    two-step and iterated estimation is available. For inference
    and specification
    testing, Windmeijer (2005) <doi:10.1016/j.jeconom.2004.02.005>
    and doubly corrected standard errors
    (Hwang, Kang, Lee, 2021 <doi:10.1016/j.jeconom.2020.09.010>)
    are available. Additionally, serial correlation tests, tests for
    overidentification, and Wald tests are provided. Functions for
    visualizing panel data structures and modeling results obtained
    from GMM estimation are also available. The plot methods include
    functions to plot unbalanced panel structure, coefficient ranges
    and coefficient paths across GMM iterations (the latter is
    implemented according to the plot shown in
    Hansen and Lee, 2021 <doi:10.3982/ECTA16274>).
    For a more detailed description of the GMM-based functionality,
    please see Fritsch, Pua, Schnurbus (2021) <doi:10.32614/RJ-2021-035>.
    For more details on the IV-based estimation routines,
    see Fritsch, Pua, and Schnurbus (WP, 2024) and
    Han and Phillips (2010) <doi:10.1017/S026646660909063X>.
License: GPL (>= 2)
URL: https://github.com/markusfritsch/pdynmc
BugReports: https://github.com/markusfritsch/pdynmc/issues
VignetteBuilder: R.rsp
Encoding: UTF-8
Classification/JEL: C23, C26, C87
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-02-20 17:18:41 UTC; Markus
Author: Markus Fritsch [aut, cre],
  Joachim Schnurbus [aut],
  Andrew Adrian Yu Pua [aut]
Maintainer: Markus Fritsch <Markus.Fritsch@uni-Passau.de>
Repository: CRAN
Date/Publication: 2025-02-20 17:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 01:30:59 UTC; unix
