# Generated by roxygen2: do not edit by hand

S3method(case.names,pdynmc)
S3method(coef,pdynmc)
S3method(dummy.coef,pdynmc)
S3method(fitted,pdynmc)
S3method(model.matrix,pdynmc)
S3method(ninst,pdynmc)
S3method(nobs,pdynmc)
S3method(optimIn,pdynmc)
S3method(plot,pdynmc)
S3method(print,pdynmc)
S3method(print,summary.pdynmc)
S3method(residuals,pdynmc)
S3method(summary,pdynmc)
S3method(variable.names,pdynmc)
S3method(vcov,pdynmc)
S3method(wmat,pdynmc)
export(FDLS)
export(NLIV)
export(NLIV.alt)
export(data.info)
export(jtest.fct)
export(mtest.fct)
export(ninst)
export(optimIn)
export(pDensTime.plot)
export(pdynmc)
export(sargan.fct)
export(strucUPD.plot)
export(wald.fct)
export(wmat)
importFrom(MASS,ginv)
importFrom(Matrix,Diagonal)
importFrom(Matrix,Matrix)
importFrom(Matrix,colMeans)
importFrom(Matrix,colSums)
importFrom(Matrix,crossprod)
importFrom(Matrix,t)
importFrom(Matrix,tcrossprod)
importFrom(Rdpack,reprompt)
importFrom(data.table,data.table)
importFrom(data.table,is.data.table)
importFrom(data.table,setDT)
importFrom(data.table,setorderv)
importFrom(data.table,shift)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,boxplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(methods,as)
importFrom(optimx,optimx)
importFrom(stats,as.formula)
importFrom(stats,case.names)
importFrom(stats,coef)
importFrom(stats,density)
importFrom(stats,dummy.coef)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(stats,variable.names)
